==> haskell-hls-haddock-comments-plugin-1.0.0.3-159-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-haddock-comments-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-haddock-comments-plugin
version:              1.0.0.3
visibility:           public
id:                   hls-haddock-comments-plugin-1.0.0.3-JLwAvwNItLn9jxMAzFn0XV
key:                  hls-haddock-comments-plugin-1.0.0.3-JLwAvwNItLn9jxMAzFn0XV
license:              Apache-2.0
maintainer:           berberman@yandex.com
author:               Potato Hatsue
homepage:             https://github.com/haskell/haskell-language-server
synopsis:             Haddock comments plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server>

category:             Development
abi:                  8385c4936bf16a81a82b1d4a1dfa9da5
exposed:              True
exposed-modules:      Ide.Plugin.HaddockComments
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/hls-haddock-comments-plugin-1.0.0.3

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/hls-haddock-comments-plugin-1.0.0.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-haddock-comments-plugin
hs-libraries:
    HShls-haddock-comments-plugin-1.0.0.3-JLwAvwNItLn9jxMAzFn0XV

depends:
    base-4.15.1.0 containers-0.6.4.1 ghc-9.0.2
    ghc-exactprint-0.6.4-6YAvXVsvUI9CHT4bkDkDxi
    ghcide-1.4.1.0-D3AgAVItlNl7ojyuL7Sewm
    hls-plugin-api-1.2.0.0-1rx2egVo7t9CNIbeA3bvS4
    lsp-types-1.3.0.1-DosavwTg7o5DbpgIJ92hl9 text-1.2.5.0
    unordered-containers-0.2.19.1-F6flbRdcGQH5ESgepmhKFP

haddock-interfaces:
    /usr/share/doc/haskell-hls-haddock-comments-plugin/html/hls-haddock-comments-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-haddock-comments-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-haddock-comments-plugin-1.0.0.3-166-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-haddock-comments-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-haddock-comments-plugin
version:              1.0.0.3
visibility:           public
id:                   hls-haddock-comments-plugin-1.0.0.3-HUcHA3EdioBJnbnvpY7NsI
key:                  hls-haddock-comments-plugin-1.0.0.3-HUcHA3EdioBJnbnvpY7NsI
license:              Apache-2.0
maintainer:           berberman@yandex.com
author:               Potato Hatsue
homepage:             https://github.com/haskell/haskell-language-server
synopsis:             Haddock comments plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server>

category:             Development
abi:                  4a8edc07cc33f7160da10be23708f9fe
exposed:              True
exposed-modules:      Ide.Plugin.HaddockComments
import-dirs:
    /usr/lib/ghc-9.0.2/site-local/hls-haddock-comments-plugin-1.0.0.3

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/hls-haddock-comments-plugin-1.0.0.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-haddock-comments-plugin
hs-libraries:
    HShls-haddock-comments-plugin-1.0.0.3-HUcHA3EdioBJnbnvpY7NsI

depends:
    base-4.15.1.0 containers-0.6.4.1 ghc-9.0.2
    ghc-exactprint-0.6.4-79aOKtfZTgV54ih37OcoW5
    ghcide-1.4.1.0-LAwNbJqxNAbKHFzYKmMq1D
    hls-plugin-api-1.2.0.0-7YKfvYPFNQdB13p9kv2xT3
    lsp-types-1.3.0.1-FUcEh9OlwJpGKjgojIsUBd text-1.2.5.0
    unordered-containers-0.2.19.1-BhRjg5By7kU7pLGfSxEo3F

haddock-interfaces:
    /usr/share/doc/haskell-hls-haddock-comments-plugin/html/hls-haddock-comments-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-haddock-comments-plugin/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
